@@ -41,6 +41,9 @@
     tildenegated <- badnames <- logical(length(funargs))
     cols <- vector(mode = "list", length = length(funargs))
     for (i in seq(length(funargs))) {
+        if (grepl("\\*|\\+", funargs[i])) {
+            admisc::stopError("Expressions not allowed, there should only be individual conditions.")
+        }
         badnames[i] <- grepl("\\(|:", funargs[i])
         cols[[i]] <- admisc::getName(admisc::notilde(funargs[i]))
         tildenegated[i] <- admisc::tilde1st(funargs[i])
