@@ -272,9 +272,17 @@
             incl.cov.e <- incl.cov[essential.PIs.rows, , drop = FALSE]
             incl.cov <- incl.cov[!essential.PIs.rows, , drop = FALSE]
             for (i in seq(ind.len)) {
-                unique.coverages <- formatC(x$individual[[i]]$incl.cov$covU[is.element(rownames(x$individual[[i]]$incl.cov), essential.PIs)], digits = 3, format = "f")
+                essentialPIs <- is.element(
+                    rownames(x$individual[[i]]$incl.cov),
+                    essential.PIs
+                )
+                unique.coverages <- formatC(
+                    x$individual[[i]]$incl.cov$covU[essentialPIs],
+                    digits = 3,
+                    format = "f"
+                )
                 incl.cov.e <- cbind(incl.cov.e, S = unique.coverages, stringsAsFactors = FALSE)
-                x$individual[[i]]$incl.cov <- x$individual[[i]]$incl.cov[!is.element(rownames(x$individual[[i]]$incl.cov), essential.PIs), ]
+                x$individual[[i]]$incl.cov <- x$individual[[i]]$incl.cov[!essentialPIs, ]
                 if (x$options$use.labels && length(x$categories) > 0) {
                     rownames(x$individual[[i]]$incl.cov) <- replaceCategories(
                         rownames(x$individual[[i]]$incl.cov),
@@ -286,14 +294,29 @@
         if (nrow(incl.cov) > 0) {
             for (i in seq(ind.len)) {
                 incl.cov <- cbind(incl.cov, "     ", stringsAsFactors = FALSE)
-                colnames(incl.cov)[ncol(incl.cov)] <- format(ifelse(ind.len < line.length, paste("(M", i, ")", sep = ""), paste("M", i, sep = "")), width = 5)
+                colnames(incl.cov)[ncol(incl.cov)] <- format(
+                    ifelse(
+                        ind.len < line.length,
+                        paste("(M", i, ")", sep = ""),
+                        paste("M", i, sep = "")
+                    ),
+                    width = 5
+                )
                 if (length(x$individual[[i]]$incl.cov$covU) > 0) {
-                    incl.cov[rownames(x$individual[[i]]$incl.cov), ncol(incl.cov)] <- formatC(x$individual[[i]]$incl.cov$covU, digits = 3, format = "f")
+                    incl.cov[rownames(x$individual[[i]]$incl.cov), ncol(incl.cov)] <- formatC(
+                        x$individual[[i]]$incl.cov$covU,
+                        digits = 3,
+                        format = "f"
+                    )
                 }
             }
         }
-        sol.incl.cov <- matrix(unlist(lapply(x$individual, "[", "sol.incl.cov")),
-                               nrow = length(x$individual), ncol = 3, byrow = TRUE)
+        sol.incl.cov <- matrix(
+            unlist(lapply(x$individual, "[", "sol.incl.cov")),
+            nrow = length(x$individual),
+            ncol = 3,
+            byrow = TRUE
+        )
         rownames(sol.incl.cov) <- paste("M", seq(length(x$individual)), sep = "")
         sol.exists <- TRUE
     }
@@ -305,7 +328,7 @@
         incl.cov[incl.cov == "  NA"] <- "     "
         colnames(incl.cov) <- format(colnames(incl.cov), justify = "centre")
         if (x$options$show.cases) {
-            max.nchar.cases <- max(5, max(nchar(encodeString(incl.cov$cases)))) 
+            max.nchar.cases <- max(5, max(nchar(encodeString(incl.cov$cases))))
             cases.column <- TRUE
             incl.cov.cases <- incl.cov$cases
             incl.cov$cases <- NULL
@@ -341,12 +364,24 @@
         nchar.rownames <- 2
     }
     if (essentials) {
-        nchar.rownames <- max(nchar.rownames, max(nchar(rownames(incl.cov.e))))
-        rownames(incl.cov.e) <- sprintf(paste("% ", nchar.rownames, "s", sep = ""), rownames(incl.cov.e))
+        nchar.rownames <- max(
+            nchar.rownames,
+            max(nchar(rownames(incl.cov.e)))
+        )
+        rownames(incl.cov.e) <- sprintf(
+            paste("% ", nchar.rownames, "s", sep = ""),
+            rownames(incl.cov.e)
+        )
     }
-    rownames(incl.cov) <- sprintf(paste("% ", nchar.rownames, "s", sep = ""), rownames(incl.cov))
+    rownames(incl.cov) <- sprintf(
+        paste("% ", nchar.rownames, "s", sep = ""),
+        rownames(incl.cov)
+    )
     if (sol.exists) {
-        rownames(sol.incl.cov) <- sprintf(paste("% ", nchar.rownames, "s", sep = ""), rownames(sol.incl.cov))
+        rownames(sol.incl.cov) <- sprintf(
+            paste("% ", nchar.rownames, "s", sep = ""),
+            rownames(sol.incl.cov)
+        )
         NAs <- is.na(sol.incl.cov)
         sol.incl.cov[!NAs] <- formatC(sol.incl.cov[!NAs], digits = 3, format = "f")
         sol.incl.cov[NAs] <- ""
@@ -354,8 +389,17 @@
     incl.cov[incl.cov == "  NA"] <- "  -  "
     max.chars <- 1
     if (is.element(x$options$relation, c("sufficiency", "suf"))) {
-        if (ncol(incl.cov) > (3 + any(grepl("PRI|RoN", colnames(incl.cov)))) & is.null(x$options$add)) {
-            first.printed.row <- paste(c(rep(" ", nchar.rownames + nchar.nrow + 25), rep("-", 7 * (ncol(incl.cov) - (2 + valid.covU)) - 2)), collapse = "")
+        if (
+            ncol(incl.cov) > (3 + any(grepl("PRI|RoN", colnames(incl.cov)))) &
+            is.null(x$options$add)
+        ) {
+            first.printed.row <- paste(
+                c(
+                    rep(" ", nchar.rownames + nchar.nrow + 25),
+                    rep("-", 7 * (ncol(incl.cov) - (2 + valid.covU)) - 2)
+                ),
+                collapse = ""
+            )
             max.chars <- nchar(first.printed.row)
         }
     }
@@ -363,22 +407,70 @@
         if (cases.column) {
             max.chars <- max.nchar.cases
         }
-        sep.row <- paste(rep("-", nchar.rownames + 7 * ncol(incl.cov) + ifelse(cases.column, max.nchar.cases, 0) + nchar.nrow), collapse = "")
+        sep.row <- paste(
+            rep(
+                "-",
+                nchar.rownames +
+                7 * ncol(incl.cov) +
+                ifelse(cases.column, max.nchar.cases, 0) +
+                nchar.nrow
+            ),
+            collapse = ""
+        )
         if (nchar(sep.row) < line.length) {
-            if (ncol(incl.cov) > (3 + any(grepl("PRI|RoN", colnames(incl.cov)))) & length(intersect(colnames(incl.cov), "pval1")) == 0 & is.null(x$options$add)) {
+            if (
+                ncol(incl.cov) > (3 + any(grepl("PRI|RoN", colnames(incl.cov)))) &
+                length(intersect(colnames(incl.cov), "pval1")) == 0 &
+                is.null(x$options$add)
+            ) {
                 cat(first.printed.row, "\n")
             }
             else {
                 cat("\n")
             }
             colstoprint <- colnames(incl.cov)
-            colnames.row <- cat(paste(c(paste(rep(" ", nchar.rownames + nchar.nrow + 2), collapse = ""), format(colstoprint)), collapse = "  "))
-            cat(paste(colnames.row, ifelse(cases.column, "  cases", ""), sep = ""), "\n")
-            sep.row <- paste(rep("-", nchar.rownames + 7 * ncol(incl.cov) + ifelse(cases.column, max.nchar.cases + 2, 0) + nchar.nrow + 2), collapse = "")
+            colnames.row <- cat(
+                paste(
+                    c(
+                        paste(
+                            rep(" ", nchar.rownames + nchar.nrow + 2),
+                            collapse = ""
+                        ),
+                        format(colstoprint)
+                    ),
+                    collapse = "  "
+                )
+            )
+            cat(
+                paste(
+                    colnames.row,
+                    ifelse(cases.column, "  cases", ""),
+                    sep = ""
+                ),
+                "\n"
+            )
+            sep.row <- paste(
+                rep(
+                    "-",
+                    nchar.rownames +
+                    7 * ncol(incl.cov) +
+                    ifelse(cases.column, max.nchar.cases + 2, 0) +
+                    nchar.nrow +
+                    2
+                ),
+                collapse = ""
+            )
             cat(sep.row, "\n")
             if (essentials) {
                 for (i in seq(nrow(incl.cov.e))) {
-                    i.row <- paste(prettyNums.e[i], paste(c(rownames(incl.cov.e)[i], incl.cov.e[i, ]), collapse = "  "), sep = "  ")
+                    i.row <- paste(
+                        prettyNums.e[i],
+                        paste(
+                            c(rownames(incl.cov.e)[i], incl.cov.e[i, ]),
+                            collapse = "  "
+                        ),
+                        sep = "  "
+                    )
                     if (cases.column) {
                         i.row <- paste(i.row, incl.cov.e.cases[i], sep = "  ")
                     }
@@ -388,7 +480,11 @@
             }
             for (i in seq(nrow(incl.cov))) {
                 rowtoprint <- c(rownames(incl.cov)[i], incl.cov[i, ])
-                i.row <- paste(prettyNums[i], paste(rowtoprint, collapse = "  "), sep = "  ")
+                i.row <- paste(
+                    prettyNums[i],
+                    paste(rowtoprint, collapse = "  "),
+                    sep = "  "
+                )
                 if (cases.column) {
                     i.row <- paste(i.row, incl.cov.cases[i], sep = "  ")
                 }
@@ -397,55 +493,204 @@
             cat(sep.row, "\n")
             if (sol.exists) {
                 for (i in seq(nrow(sol.incl.cov))) {
-                    cat(paste(paste(rep(" ", nchar.nrow), collapse = ""), paste(c(rownames(sol.incl.cov)[i], sol.incl.cov[i, ]), collapse = "  "), sep = "  "), "\n")
+                    cat(
+                        paste(
+                            paste(
+                                rep(" ", nchar.nrow),
+                                collapse = ""
+                            ),
+                            paste(
+                                c(
+                                    rownames(sol.incl.cov)[i],
+                                    sol.incl.cov[i, ]
+                                ),
+                                collapse = "  "
+                            ),
+                            sep = "  "
+                        ),
+                        "\n"
+                    )
                 }
             }
             cat("\n")
         }
         else {
-            if (ncol(incl.cov) > (3 + any(grepl("PRI|RoN", colnames(incl.cov)))) & is.null(x$options$add)) {
+            if (
+                ncol(incl.cov) > (3 + any(grepl("PRI|RoN", colnames(incl.cov)))) &
+                is.null(x$options$add)
+            ) {
                 cat(first.printed.row, "\n")
-            }
-            else {
+            } else {
                 cat("\n")
             }
-            cat(paste(c(paste(rep(" ", nchar.rownames + nchar.nrow + 2), collapse = ""), colnames(incl.cov)), collapse = "  "), "\n")
-            sep.row <- paste(rep("-", nchar.rownames + 7 * ncol(incl.cov) + nchar.nrow + 2), collapse = "")
+            cat(
+                paste(
+                    c(
+                        paste(
+                            rep(" ", nchar.rownames + nchar.nrow + 2),
+                            collapse = ""
+                        ),
+                        colnames(incl.cov)
+                    ),
+                    collapse = "  "
+                ),
+                "\n"
+            )
+            sep.row <- paste(
+                rep("-", nchar.rownames + 7 * ncol(incl.cov) + nchar.nrow + 2),
+                collapse = ""
+            )
             cat(sep.row, "\n")
             if (essentials) {
                 for (i in seq(nrow(incl.cov.e))) {
-                    cat(paste(prettyNums.e[i], paste(c(rownames(incl.cov.e)[i], incl.cov.e[i, ]), collapse = "  "), "\n"), sep = "  ")
+                    cat(
+                        paste(
+                            prettyNums.e[i],
+                            paste(
+                                c(
+                                    rownames(incl.cov.e)[i],
+                                    incl.cov.e[i, ]
+                                ),
+                                collapse = "  "
+                            ),
+                            "\n"
+                        ),
+                        sep = "  "
+                    )
                 }
                 cat(sep.row, "\n")
             }
             for (i in seq(nrow(incl.cov))) {
-                cat(paste(prettyNums[i], paste(c(rownames(incl.cov)[i], incl.cov[i, ]), collapse = "  "), sep = "  "), "\n")
+                cat(
+                    paste(
+                        prettyNums[i],
+                        paste(
+                            c(
+                                rownames(incl.cov)[i],
+                                incl.cov[i, ]
+                            ),
+                            collapse = "  "
+                        ),
+                        sep = "  "
+                    ),
+                    "\n"
+                )
             }
             cat(sep.row, "\n")
             if (sol.exists) {
                 for (i in seq(nrow(sol.incl.cov))) {
-                    cat(paste(paste(rep(" ", nchar.nrow), collapse = ""), paste(c(rownames(sol.incl.cov)[i], sol.incl.cov[i, ]), collapse = "  "), sep = "  "), "\n")
+                    cat(
+                        paste(
+                            paste(
+                                rep(" ", nchar.nrow),
+                                collapse = ""
+                            ),
+                            paste(
+                                c(
+                                    rownames(sol.incl.cov)[i],
+                                    sol.incl.cov[i, ]
+                                ),
+                                collapse = "  "
+                            ),
+                            sep = "  "
+                        ),
+                        "\n"
+                    )
                 }
             }
             if (cases.column) {
-                cat("\n", paste(paste(rep(" ", nchar.rownames + nchar.nrow + 2), collapse = ""), "cases"), "\n")
-                cat(paste(rep("-", nchar.rownames + 7 + nchar.nrow + 2), collapse = ""), "\n")
+                cat(
+                    "\n",
+                    paste(
+                        paste(
+                            rep(" ", nchar.rownames + nchar.nrow + 2),
+                            collapse = ""
+                        ),
+                        "cases"
+                    ),
+                    "\n"
+                )
+                cat(
+                    paste(
+                        rep("-", nchar.rownames + 7 + nchar.nrow + 2),
+                        collapse = ""
+                    ),
+                    "\n"
+                )
                 if (essentials) {
                     for (i in seq(nrow(incl.cov.e))) {
-                        cat(paste(prettyNums.e[i], paste(rownames(incl.cov.e)[i], " "), sep = "  "))
-                        cases <- unlist(strsplit(incl.cov.e.cases[i], split = "; ", useBytes = TRUE))
-                        cat(admisc::prettyString(cases, getOption("width") - nchar.rownames - nchar.nrow - 4, nchar.rownames + nchar.nrow + 4, ";", cases = TRUE))
+                        cat(
+                            paste(
+                                prettyNums.e[i],
+                                paste(
+                                    rownames(incl.cov.e)[i],
+                                    " "
+                                ),
+                                sep = "  "
+                            )
+                        )
+                        cases <- unlist(
+                            strsplit(
+                                incl.cov.e.cases[i],
+                                split = "; ",
+                                useBytes = TRUE
+                            )
+                        )
+                        cat(
+                            admisc::prettyString(
+                                cases,
+                                getOption("width") - nchar.rownames - nchar.nrow - 4,
+                                nchar.rownames + nchar.nrow + 4,
+                                ";",
+                                cases = TRUE
+                            )
+                        )
                         cat("\n")
                     }
-                    cat(paste(rep("-", nchar.rownames + nchar.nrow + 9), collapse = ""), "\n")
+                    cat(
+                        paste(
+                            rep("-", nchar.rownames + nchar.nrow + 9),
+                            collapse = ""
+                        ),
+                        "\n"
+                    )
                 }
                 for (i in seq(nrow(incl.cov))) {
-                    cat(paste(prettyNums[i], paste(rownames(incl.cov)[i], " "), sep = "  "))
-                    cases <- unlist(strsplit(incl.cov.cases[i], split = "; ", useBytes = TRUE))
-                    cat(admisc::prettyString(cases, getOption("width") - nchar.rownames - nchar.nrow - 4, nchar.rownames + nchar.nrow + 4, ";", cases = TRUE))
+                    cat(
+                        paste(
+                            prettyNums[i],
+                            paste(
+                                rownames(incl.cov)[i],
+                                " "
+                            ),
+                            sep = "  "
+                        )
+                    )
+                    cases <- unlist(
+                        strsplit(
+                            incl.cov.cases[i],
+                            split = "; ",
+                            useBytes = TRUE
+                        )
+                    )
+                    cat(
+                        admisc::prettyString(
+                            cases,
+                            getOption("width") - nchar.rownames - nchar.nrow - 4,
+                            nchar.rownames + nchar.nrow + 4,
+                            ";",
+                            cases = TRUE
+                        )
+                    )
                     cat("\n")
                 }
-                cat(paste(rep("-", nchar.rownames + nchar.nrow + 9), collapse = ""), "\n\n")
+                cat(
+                    paste(
+                        rep("-", nchar.rownames + nchar.nrow + 9),
+                        collapse = ""
+                    ),
+                    "\n\n"
+                )
             }
         }
     }
@@ -1217,7 +1462,14 @@
         names.mydata <- colnames(x$recoded.data)[seq(nofconditions + 1)]
         if (!is.element("removed", names(x$options))) {
             if (enter) cat("\n")
-            if (!all(is.element(names(x$tt)[seq(nofconditions)], names(x$recoded.data)[seq(nofconditions)]))) {
+            if (
+                !all(
+                    is.element(
+                        names(x$tt)[seq(nofconditions)],
+                        names(x$recoded.data)[seq(nofconditions)]
+                    )
+                )
+            ) {
                 for (i in seq(nofconditions)) {
                     cat("    ", paste(names(x$tt)[i], ": ", sep = ""), names.mydata[i], "\n", sep = "")
                 }
@@ -1261,9 +1513,23 @@
                 cat("  DCC: deviant cases consistency\n")
             }
             if (any(names(x$tt) == "pval1")) {
-                cat(paste("pval1: p-value for alternative hypothesis inclusion > ", x$options$incl.cut[1], "\n", sep = ""))
+                cat(
+                    paste(
+                        "pval1: p-value for alternative hypothesis inclusion > ",
+                        x$options$incl.cut[1],
+                        "\n",
+                        sep = ""
+                    )
+                )
                 if (length(x$options$incl.cut) > 1) {
-                    cat(paste("pval0: p-value for alternative hypothesis inclusion > ", x$options$incl.cut[2], "\n", sep = ""))
+                    cat(
+                        paste(
+                            "pval0: p-value for alternative hypothesis inclusion > ",
+                            x$options$incl.cut[2],
+                            "\n",
+                            sep = ""
+                        )
+                    )
                 }
             }
             cat("\n")
@@ -1287,9 +1553,16 @@
         print(admisc::prettyTable(x$tt))
         if (alloutzero) {
             if (enter) cat("\n")
-            cat(paste("It seems that all output values have been coded to zero.",
-                      "Suggestion: lower the inclusion score for the presence of the outcome,",
-                      sprintf("the relevant argument is \"incl.cut\" which now has a value of %s.\n", x$options$incl.cut[1]), sep = "\n"))
+            cat(
+                paste(
+                    "It seems that all output values have been coded to zero.",
+                    "Suggestion: lower the inclusion score for the presence of the outcome,",
+                    sprintf(
+                        "the relevant argument is \"incl.cut\" which now has a value of %s.\n", x$options$incl.cut[1]
+                    ),
+                    sep = "\n"
+                )
+            )
         }
         if (enter) cat("\n")
     }
